# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictStr


class TableDetailsResponse(BaseModel):
    """
    `TableDetailsResponse`

    Response containing details about a database table including its name, database, and schema information.
    """

    name: Optional[StrictStr] = Field(default=None, description="The name of the table")
    database: Optional[StrictStr] = Field(
        default=None, description="The database containing the table"
    )
    var_schema: Optional[StrictStr] = Field(
        default=None, alias="schema", description="The schema containing the table"
    )
    __properties = ["name", "database", "schema"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TableDetailsResponse:
        """Create an instance of TableDetailsResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TableDetailsResponse:
        """Create an instance of TableDetailsResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return TableDetailsResponse.parse_obj(obj)

        _obj = TableDetailsResponse.parse_obj(
            {
                "name": obj.get("name"),
                "database": obj.get("database"),
                "var_schema": obj.get("schema"),
            }
        )
        return _obj
