# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import BaseModel, Field, constr


class BrowseBucketDataSourceRequest(BaseModel):
    """
    `BrowseBucketDataSourceRequest`

    Request to browse the contents of a bucket DataSource at the specified path, returning a list of available files and folders.
    """

    path: constr(strict=True, max_length=1000) = Field(
        default=...,
        description="The path within the bucket where the data files are located",
    )
    __properties = ["path"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BrowseBucketDataSourceRequest:
        """Create an instance of BrowseBucketDataSourceRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BrowseBucketDataSourceRequest:
        """Create an instance of BrowseBucketDataSourceRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return BrowseBucketDataSourceRequest.parse_obj(obj)

        _obj = BrowseBucketDataSourceRequest.parse_obj({"path": obj.get("path")})
        return _obj
