# coding: utf-8

"""
Earnix Elevate Import Export API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint

from pydantic.v1 import Field, constr

from earnix_elevate.clients.imx.models.snowflake_auth_request import (
    SnowflakeAuthRequest,
)


class SnowflakePasswordAuthRequest(SnowflakeAuthRequest):
    """
    `SnowflakePasswordAuthRequest`

    Snowflake authentication request using username/password authentication, requiring user credentials and connection host information.
    """

    username: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., description="The Snowflake username for authentication"
    )
    password: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., description="The Snowflake password for authentication"
    )
    host: constr(strict=True, max_length=500, min_length=3) = Field(
        default=..., description="The Snowflake host/account identifier"
    )
    __properties = ["authType", "username", "password", "host"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SnowflakePasswordAuthRequest:
        """Create an instance of SnowflakePasswordAuthRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SnowflakePasswordAuthRequest:
        """Create an instance of SnowflakePasswordAuthRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return SnowflakePasswordAuthRequest.parse_obj(obj)

        _obj = SnowflakePasswordAuthRequest.parse_obj(
            {
                "auth_type": obj.get("authType"),
                "username": obj.get("username"),
                "password": obj.get("password"),
                "host": obj.get("host"),
            }
        )
        return _obj
