# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, conlist

from earnix_elevate.clients.data.models.data_set_edge_response import (
    DataSetEdgeResponse,
)


class DataSetEdgesResponse(BaseModel):
    """
    `DataSetEdgesResponse`
    """

    edges: Optional[conlist(DataSetEdgeResponse)] = Field(
        default=None,
        description="List of all connections between nodes in the transformation graph, defining the data flow",
    )
    __properties = ["edges"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DataSetEdgesResponse:
        """Create an instance of DataSetEdgesResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each item in edges (list)
        _items = []
        if self.edges:
            for _item in self.edges:
                if _item:
                    _items.append(_item.to_dict())
            _dict["edges"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DataSetEdgesResponse:
        """Create an instance of DataSetEdgesResponse from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return DataSetEdgesResponse.parse_obj(obj)

        _obj = DataSetEdgesResponse.parse_obj(
            {
                "edges": [
                    DataSetEdgeResponse.from_dict(_item) for _item in obj.get("edges")
                ]
                if obj.get("edges") is not None
                else None
            }
        )
        return _obj
