# coding: utf-8

"""
Earnix Elevate Data API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.0.1
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""

from __future__ import annotations

import json
import pprint
from typing import Optional

from pydantic.v1 import BaseModel, Field, StrictStr


class ExportS3Response(BaseModel):
    """
    `ExportS3Response`
    """

    job_id: Optional[StrictStr] = Field(
        default=None,
        alias="jobId",
        description="Unique identifier for tracking the S3 export job status and progress",
    )
    __properties = ["jobId"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ExportS3Response:
        """Create an instance of ExportS3Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ExportS3Response:
        """Create an instance of ExportS3Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return ExportS3Response.parse_obj(obj)

        _obj = ExportS3Response.parse_obj({"job_id": obj.get("jobId")})
        return _obj
